# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/tools/sensor_calibration/proto/extractor_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/tools/sensor_calibration/proto/extractor_config.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=modules/tools/sensor_calibration/proto/extractor_config.proto\"\xa2\x01\n\x08IoConfig\x12\x16\n\ttask_name\x18\x01 \x02(\t:\x03tmp\x12#\n\x0boutput_path\x18\x02 \x02(\t:\x0e\x65xtracted_data\x12\"\n\x0fstart_timestamp\x18\x03 \x01(\t:\tFLOAT_MIN\x12 \n\rend_timestamp\x18\x04 \x01(\t:\tFLOAT_MAX\x12\x13\n\x0bmain_sensor\x18\x05 \x01(\t\"P\n\rChannelConfig\x12\x15\n\x0b\x64\x65scription\x18\x01 \x01(\t:\x00\x12\x0c\n\x04name\x18\x02 \x02(\t\x12\x1a\n\x0f\x65xtraction_rate\x18\x03 \x02(\r:\x01\x31\"+\n\x08\x43hannels\x12\x1f\n\x07\x63hannel\x18\x01 \x03(\x0b\x32\x0e.ChannelConfig\"\x1e\n\x07Records\x12\x13\n\x0brecord_path\x18\x01 \x03(\t\"l\n\x14\x44\x61taExtractionConfig\x12\x1c\n\tio_config\x18\x01 \x02(\x0b\x32\t.IoConfig\x12\x1b\n\x08\x63hannels\x18\x02 \x02(\x0b\x32\t.Channels\x12\x19\n\x07records\x18\x03 \x02(\x0b\x32\x08.Records'
)




_IOCONFIG = _descriptor.Descriptor(
  name='IoConfig',
  full_name='IoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_name', full_name='IoConfig.task_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=b"tmp".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_path', full_name='IoConfig.output_path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=b"extracted_data".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='IoConfig.start_timestamp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"FLOAT_MIN".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='IoConfig.end_timestamp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"FLOAT_MAX".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_sensor', full_name='IoConfig.main_sensor', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=228,
)


_CHANNELCONFIG = _descriptor.Descriptor(
  name='ChannelConfig',
  full_name='ChannelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='ChannelConfig.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ChannelConfig.name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extraction_rate', full_name='ChannelConfig.extraction_rate', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=310,
)


_CHANNELS = _descriptor.Descriptor(
  name='Channels',
  full_name='Channels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='Channels.channel', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=355,
)


_RECORDS = _descriptor.Descriptor(
  name='Records',
  full_name='Records',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='record_path', full_name='Records.record_path', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=387,
)


_DATAEXTRACTIONCONFIG = _descriptor.Descriptor(
  name='DataExtractionConfig',
  full_name='DataExtractionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='io_config', full_name='DataExtractionConfig.io_config', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channels', full_name='DataExtractionConfig.channels', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records', full_name='DataExtractionConfig.records', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=497,
)

_CHANNELS.fields_by_name['channel'].message_type = _CHANNELCONFIG
_DATAEXTRACTIONCONFIG.fields_by_name['io_config'].message_type = _IOCONFIG
_DATAEXTRACTIONCONFIG.fields_by_name['channels'].message_type = _CHANNELS
_DATAEXTRACTIONCONFIG.fields_by_name['records'].message_type = _RECORDS
DESCRIPTOR.message_types_by_name['IoConfig'] = _IOCONFIG
DESCRIPTOR.message_types_by_name['ChannelConfig'] = _CHANNELCONFIG
DESCRIPTOR.message_types_by_name['Channels'] = _CHANNELS
DESCRIPTOR.message_types_by_name['Records'] = _RECORDS
DESCRIPTOR.message_types_by_name['DataExtractionConfig'] = _DATAEXTRACTIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IoConfig = _reflection.GeneratedProtocolMessageType('IoConfig', (_message.Message,), {
  'DESCRIPTOR' : _IOCONFIG,
  '__module__' : 'modules.tools.sensor_calibration.proto.extractor_config_pb2'
  # @@protoc_insertion_point(class_scope:IoConfig)
  })
_sym_db.RegisterMessage(IoConfig)

ChannelConfig = _reflection.GeneratedProtocolMessageType('ChannelConfig', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELCONFIG,
  '__module__' : 'modules.tools.sensor_calibration.proto.extractor_config_pb2'
  # @@protoc_insertion_point(class_scope:ChannelConfig)
  })
_sym_db.RegisterMessage(ChannelConfig)

Channels = _reflection.GeneratedProtocolMessageType('Channels', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELS,
  '__module__' : 'modules.tools.sensor_calibration.proto.extractor_config_pb2'
  # @@protoc_insertion_point(class_scope:Channels)
  })
_sym_db.RegisterMessage(Channels)

Records = _reflection.GeneratedProtocolMessageType('Records', (_message.Message,), {
  'DESCRIPTOR' : _RECORDS,
  '__module__' : 'modules.tools.sensor_calibration.proto.extractor_config_pb2'
  # @@protoc_insertion_point(class_scope:Records)
  })
_sym_db.RegisterMessage(Records)

DataExtractionConfig = _reflection.GeneratedProtocolMessageType('DataExtractionConfig', (_message.Message,), {
  'DESCRIPTOR' : _DATAEXTRACTIONCONFIG,
  '__module__' : 'modules.tools.sensor_calibration.proto.extractor_config_pb2'
  # @@protoc_insertion_point(class_scope:DataExtractionConfig)
  })
_sym_db.RegisterMessage(DataExtractionConfig)


# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc
from grpc.framework.common import cardinality
from grpc.framework.interfaces.face import utilities as face_utilities

import modules.map.tools.map_datachecker.proto.collection_check_message_pb2 as modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2


class CollectionCheckerServiceStub(object):
  """MAP
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ServiceDynamicAlign = channel.unary_unary(
        '/apollo.hdmap.CollectionCheckerService/ServiceDynamicAlign',
        request_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.DynamicAlignRequest.SerializeToString,
        response_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.DynamicAlignResponse.FromString,
        )
    self.ServiceStaticAlign = channel.unary_unary(
        '/apollo.hdmap.CollectionCheckerService/ServiceStaticAlign',
        request_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.StaticAlignRequest.SerializeToString,
        response_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.StaticAlignResponse.FromString,
        )
    self.ServiceEightRoute = channel.unary_unary(
        '/apollo.hdmap.CollectionCheckerService/ServiceEightRoute',
        request_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.EightRouteRequest.SerializeToString,
        response_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.EightRouteResponse.FromString,
        )
    self.ServiceChannelVerify = channel.unary_unary(
        '/apollo.hdmap.CollectionCheckerService/ServiceChannelVerify',
        request_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.ChannelVerifyRequest.SerializeToString,
        response_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.ChannelVerifyResponse.FromString,
        )
    self.ServiceLoopsVerify = channel.unary_unary(
        '/apollo.hdmap.CollectionCheckerService/ServiceLoopsVerify',
        request_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.LoopsVerifyRequest.SerializeToString,
        response_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.LoopsVerifyResponse.FromString,
        )


class CollectionCheckerServiceServicer(object):
  """MAP
  """

  def ServiceDynamicAlign(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ServiceStaticAlign(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ServiceEightRoute(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ServiceChannelVerify(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ServiceLoopsVerify(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CollectionCheckerServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ServiceDynamicAlign': grpc.unary_unary_rpc_method_handler(
          servicer.ServiceDynamicAlign,
          request_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.DynamicAlignRequest.FromString,
          response_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.DynamicAlignResponse.SerializeToString,
      ),
      'ServiceStaticAlign': grpc.unary_unary_rpc_method_handler(
          servicer.ServiceStaticAlign,
          request_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.StaticAlignRequest.FromString,
          response_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.StaticAlignResponse.SerializeToString,
      ),
      'ServiceEightRoute': grpc.unary_unary_rpc_method_handler(
          servicer.ServiceEightRoute,
          request_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.EightRouteRequest.FromString,
          response_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.EightRouteResponse.SerializeToString,
      ),
      'ServiceChannelVerify': grpc.unary_unary_rpc_method_handler(
          servicer.ServiceChannelVerify,
          request_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.ChannelVerifyRequest.FromString,
          response_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.ChannelVerifyResponse.SerializeToString,
      ),
      'ServiceLoopsVerify': grpc.unary_unary_rpc_method_handler(
          servicer.ServiceLoopsVerify,
          request_deserializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.LoopsVerifyRequest.FromString,
          response_serializer=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.LoopsVerifyResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'apollo.hdmap.CollectionCheckerService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/radar_component_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/radar_component_config.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=modules/perception/onboard/proto/radar_component_config.proto\x12\x19\x61pollo.perception.onboard\"\x82\x02\n\x14RadarComponentConfig\x12\x12\n\nradar_name\x18\x01 \x01(\t\x12\x19\n\x11tf_child_frame_id\x18\x02 \x01(\t\x12\x1e\n\x16radar_forward_distance\x18\x03 \x01(\x01\x12!\n\x19radar_preprocessor_method\x18\x04 \x01(\t\x12\x1f\n\x17radar_perception_method\x18\x05 \x01(\t\x12\x1b\n\x13radar_pipeline_name\x18\x06 \x01(\t\x12\x1d\n\x15odometry_channel_name\x18\x07 \x01(\t\x12\x1b\n\x13output_channel_name\x18\x08 \x01(\t'
)




_RADARCOMPONENTCONFIG = _descriptor.Descriptor(
  name='RadarComponentConfig',
  full_name='apollo.perception.onboard.RadarComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='radar_name', full_name='apollo.perception.onboard.RadarComponentConfig.radar_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tf_child_frame_id', full_name='apollo.perception.onboard.RadarComponentConfig.tf_child_frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_forward_distance', full_name='apollo.perception.onboard.RadarComponentConfig.radar_forward_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_preprocessor_method', full_name='apollo.perception.onboard.RadarComponentConfig.radar_preprocessor_method', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_perception_method', full_name='apollo.perception.onboard.RadarComponentConfig.radar_perception_method', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_pipeline_name', full_name='apollo.perception.onboard.RadarComponentConfig.radar_pipeline_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='odometry_channel_name', full_name='apollo.perception.onboard.RadarComponentConfig.odometry_channel_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_channel_name', full_name='apollo.perception.onboard.RadarComponentConfig.output_channel_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=351,
)

DESCRIPTOR.message_types_by_name['RadarComponentConfig'] = _RADARCOMPONENTCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RadarComponentConfig = _reflection.GeneratedProtocolMessageType('RadarComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _RADARCOMPONENTCONFIG,
  '__module__' : 'modules.perception.onboard.proto.radar_component_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.RadarComponentConfig)
  })
_sym_db.RegisterMessage(RadarComponentConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/third_party_perception/proto/third_party_perception_component.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/third_party_perception/proto/third_party_perception_component.proto',
  package='apollo.third_party_perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKmodules/third_party_perception/proto/third_party_perception_component.proto\x12\x1d\x61pollo.third_party_perception\"p\n\x1aThirdPartyPerceptionDevice\x12R\n\x0b\x64\x65vice_type\x18\x01 \x01(\x0e\x32=.apollo.third_party_perception.ThirdPartyPerceptionDeviceType*>\n\x1eThirdPartyPerceptionDeviceType\x12\x0e\n\nSMARTEREYE\x10\x00\x12\x0c\n\x08MOBILEYE\x10\x01'
)

_THIRDPARTYPERCEPTIONDEVICETYPE = _descriptor.EnumDescriptor(
  name='ThirdPartyPerceptionDeviceType',
  full_name='apollo.third_party_perception.ThirdPartyPerceptionDeviceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMARTEREYE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOBILEYE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=224,
  serialized_end=286,
)
_sym_db.RegisterEnumDescriptor(_THIRDPARTYPERCEPTIONDEVICETYPE)

ThirdPartyPerceptionDeviceType = enum_type_wrapper.EnumTypeWrapper(_THIRDPARTYPERCEPTIONDEVICETYPE)
SMARTEREYE = 0
MOBILEYE = 1



_THIRDPARTYPERCEPTIONDEVICE = _descriptor.Descriptor(
  name='ThirdPartyPerceptionDevice',
  full_name='apollo.third_party_perception.ThirdPartyPerceptionDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_type', full_name='apollo.third_party_perception.ThirdPartyPerceptionDevice.device_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=222,
)

_THIRDPARTYPERCEPTIONDEVICE.fields_by_name['device_type'].enum_type = _THIRDPARTYPERCEPTIONDEVICETYPE
DESCRIPTOR.message_types_by_name['ThirdPartyPerceptionDevice'] = _THIRDPARTYPERCEPTIONDEVICE
DESCRIPTOR.enum_types_by_name['ThirdPartyPerceptionDeviceType'] = _THIRDPARTYPERCEPTIONDEVICETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ThirdPartyPerceptionDevice = _reflection.GeneratedProtocolMessageType('ThirdPartyPerceptionDevice', (_message.Message,), {
  'DESCRIPTOR' : _THIRDPARTYPERCEPTIONDEVICE,
  '__module__' : 'modules.third_party_perception.proto.third_party_perception_component_pb2'
  # @@protoc_insertion_point(class_scope:apollo.third_party_perception.ThirdPartyPerceptionDevice)
  })
_sym_db.RegisterMessage(ThirdPartyPerceptionDevice)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/scenario.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/scenario.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'modules/prediction/proto/scenario.proto\x12\x11\x61pollo.prediction\"\xe8\x01\n\x08Scenario\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32 .apollo.prediction.Scenario.Type:\x07UNKNOWN\x12\x13\n\x0bjunction_id\x18\x02 \x01(\t\"\x8d\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x06\x43RUISE\x10\xe8\x07\x12\x11\n\x0c\x43RUISE_URBAN\x10\xe9\x07\x12\x13\n\x0e\x43RUISE_HIGHWAY\x10\xea\x07\x12\r\n\x08JUNCTION\x10\xd0\x0f\x12\x1b\n\x16JUNCTION_TRAFFIC_LIGHT\x10\xd1\x0f\x12\x17\n\x12JUNCTION_STOP_SIGN\x10\xd2\x0f'
)



_SCENARIO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.prediction.Scenario.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE', index=1, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_URBAN', index=2, number=1001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_HIGHWAY', index=3, number=1002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION', index=4, number=2000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION_TRAFFIC_LIGHT', index=5, number=2001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION_STOP_SIGN', index=6, number=2002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=154,
  serialized_end=295,
)
_sym_db.RegisterEnumDescriptor(_SCENARIO_TYPE)


_SCENARIO = _descriptor.Descriptor(
  name='Scenario',
  full_name='apollo.prediction.Scenario',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.prediction.Scenario.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='apollo.prediction.Scenario.junction_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCENARIO_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=295,
)

_SCENARIO.fields_by_name['type'].enum_type = _SCENARIO_TYPE
_SCENARIO_TYPE.containing_type = _SCENARIO
DESCRIPTOR.message_types_by_name['Scenario'] = _SCENARIO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scenario = _reflection.GeneratedProtocolMessageType('Scenario', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIO,
  '__module__' : 'modules.prediction.proto.scenario_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Scenario)
  })
_sym_db.RegisterMessage(Scenario)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/open_space_task_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.planning.proto import planner_open_space_config_pb2 as modules_dot_planning_dot_proto_dot_planner__open__space__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/open_space_task_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3modules/planning/proto/open_space_task_config.proto\x12\x0f\x61pollo.planning\x1a\x36modules/planning/proto/planner_open_space_config.proto\"\xe6\x01\n\x1eOpenSpaceFallBackDeciderConfig\x12,\n!open_space_prediction_time_period\x18\x01 \x01(\x01:\x01\x35\x12\x31\n&open_space_fallback_collision_distance\x18\x02 \x01(\x01:\x01\x35\x12,\n!open_space_fallback_stop_distance\x18\x03 \x01(\x01:\x01\x32\x12\x35\n)open_space_fallback_collision_time_buffer\x18\x04 \x01(\x01:\x02\x31\x30\"\x86\x02\n\x1dOpenSpacePreStopDeciderConfig\x12J\n\tstop_type\x18\x01 \x01(\x0e\x32\x37.apollo.planning.OpenSpacePreStopDeciderConfig.StopType\x12\"\n\x17rightaway_stop_distance\x18\x02 \x01(\x01:\x01\x32\x12\"\n\x17stop_distance_to_target\x18\x03 \x01(\x01:\x01\x35\"Q\n\x08StopType\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x0b\n\x07PARKING\x10\x01\x12\r\n\tPULL_OVER\x10\x02\x12\x18\n\x14NARROW_STREET_U_TURN\x10\x03\"\xc8\x05\n\x19OpenSpaceRoiDeciderConfig\x12\x44\n\x08roi_type\x18\x01 \x01(\x0e\x32\x32.apollo.planning.OpenSpaceRoiDeciderConfig.RoiType\x12(\n\x1croi_longitudinal_range_start\x18\x02 \x01(\x01:\x02\x31\x30\x12&\n\x1aroi_longitudinal_range_end\x18\x03 \x01(\x01:\x02\x31\x30\x12\x1e\n\x13parking_start_range\x18\x04 \x01(\x01:\x01\x37\x12\x1e\n\x0fparking_inwards\x18\x05 \x01(\x08:\x05\x66\x61lse\x12#\n\x1b\x65nable_perception_obstacles\x18\x06 \x01(\x08\x12!\n\x14parking_depth_buffer\x18\x07 \x01(\x01:\x03\x30.1\x12\'\n\x1aroi_line_segment_min_angle\x18\x08 \x01(\x01:\x03\x30.3\x12\"\n\x17roi_line_segment_length\x18\t \x01(\x01:\x01\x31\x12,\n roi_line_segment_length_from_map\x18\n \x01(\x01:\x02\x31\x30\x12\x34\n&perception_obstacle_filtering_distance\x18\x0b \x01(\x01:\x04\x31\x30\x30\x30\x12\"\n\x1aperception_obstacle_buffer\x18\x0c \x01(\x01\x12\x32\n\'curb_heading_tangent_change_upper_limit\x18\r \x01(\x01:\x01\x31\x12\x1f\n\x13\x65nd_pose_s_distance\x18\x0e \x01(\x01:\x02\x31\x30\"a\n\x07RoiType\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x0b\n\x07PARKING\x10\x01\x12\r\n\tPULL_OVER\x10\x02\x12\x0f\n\x0bPARK_AND_GO\x10\x03\x12\x18\n\x14NARROW_STREET_U_TURN\x10\x04\"\x82\x04\n\"OpenSpaceTrajectoryPartitionConfig\x12\x18\n\x10gear_shift_max_t\x18\x01 \x01(\x01\x12\x19\n\x11gear_shift_unit_t\x18\x02 \x01(\x01\x12\"\n\x1agear_shift_period_duration\x18\x03 \x01(\x01\x12\x1f\n\x17interpolated_pieces_num\x18\x04 \x01(\x04\x12\"\n\x1ainitial_gear_check_horizon\x18\x05 \x01(\x04\x12\x1c\n\x14heading_search_range\x18\x06 \x01(\x01\x12\x1b\n\x13heading_track_range\x18\x07 \x01(\x01\x12$\n\x15\x64istance_search_range\x18\x08 \x01(\x01:\x05\x31\x65-06\x12\"\n\x1aheading_offset_to_midpoint\x18\t \x01(\x01\x12\'\n\x1alateral_offset_to_midpoint\x18\n \x01(\x01:\x03\x30.1\x12,\n\x1flongitudinal_offset_to_midpoint\x18\x0b \x01(\x01:\x03\x30.1\x12\x33\n%vehicle_box_iou_threshold_to_midpoint\x18\x0c \x01(\x01:\x04\x30.95\x12-\n linear_velocity_threshold_on_ego\x18\r \x01(\x01:\x03\x30.2\"\x88\x01\n!OpenSpaceTrajectoryProviderConfig\x12\x63\n&open_space_trajectory_optimizer_config\x18\x01 \x01(\x0b\x32\x33.apollo.planning.OpenSpaceTrajectoryOptimizerConfig\"\xb5\x03\n\"OpenSpaceTrajectoryOptimizerConfig\x12@\n\x14hybrid_a_star_config\x18\x01 \x01(\x0b\x32\".apollo.planning.HybridAStarConfig\x12L\n\x1f\x64ual_variable_warm_start_config\x18\x02 \x01(\x0b\x32#.apollo.planning.DualVariableConfig\x12o\n,distance_approach_trajectory_smoother_config\x18\x03 \x01(\x0b\x32\x39.apollo.planning.DistanceApproachTrajectorySmootherConfig\x12\x14\n\x07\x64\x65lta_t\x18\x04 \x01(\x02:\x03\x30.5\x12,\n\x1dis_near_destination_threshold\x18\x05 \x01(\x01:\x05\x30.001\x12J\n\x19planner_open_space_config\x18\x06 \x01(\x0b\x32\'.apollo.planning.PlannerOpenSpaceConfig\"\xf9\x02\n\x11HybridAStarConfig\x12\x1f\n\x12xy_grid_resolution\x18\x01 \x01(\x01:\x03\x30.2\x12!\n\x13phi_grid_resolution\x18\x02 \x01(\x01:\x04\x30.05\x12\x19\n\rnext_node_num\x18\x03 \x01(\x04:\x02\x31\x30\x12\x16\n\tstep_size\x18\x04 \x01(\x01:\x03\x30.5\x12\x1f\n\x14traj_forward_penalty\x18\x05 \x01(\x01:\x01\x30\x12\x1c\n\x11traj_back_penalty\x18\x06 \x01(\x01:\x01\x30\x12$\n\x18traj_gear_switch_penalty\x18\x07 \x01(\x01:\x02\x31\x30\x12\x1f\n\x12traj_steer_penalty\x18\x08 \x01(\x01:\x03\x31\x30\x30\x12%\n\x19traj_steer_change_penalty\x18\t \x01(\x01:\x02\x31\x30\x12&\n\x19grid_a_star_xy_resolution\x18\x0f \x01(\x01:\x03\x30.1\x12\x18\n\x0bnode_radius\x18\x10 \x01(\x01:\x03\x30.5\"\xe5\x01\n\x12\x44ualVariableConfig\x12\x13\n\x08weight_d\x18\x01 \x01(\x01:\x01\x31\x12\x38\n\x0cipopt_config\x18\x02 \x01(\x0b\x32\".apollo.planning.IpoptSolverConfig\x12\x34\n\tqp_format\x18\x03 \x01(\x0e\x32!.apollo.planning.DualVariableMode\x12\x1e\n\x13min_safety_distance\x18\x04 \x01(\x01:\x01\x30\x12\x19\n\ndebug_osqp\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x04\x62\x65ta\x18\x06 \x01(\x01:\x01\x31\"\xa2\x06\n(DistanceApproachTrajectorySmootherConfig\x12\x14\n\x0cweight_steer\x18\x01 \x01(\x01\x12\x10\n\x08weight_a\x18\x02 \x01(\x01\x12\x19\n\x11weight_steer_rate\x18\x03 \x01(\x01\x12\x15\n\rweight_a_rate\x18\x04 \x01(\x01\x12\x10\n\x08weight_x\x18\x05 \x01(\x01\x12\x10\n\x08weight_y\x18\x06 \x01(\x01\x12\x12\n\nweight_phi\x18\x07 \x01(\x01\x12\x10\n\x08weight_v\x18\x08 \x01(\x01\x12\x1e\n\x16weight_steer_stitching\x18\t \x01(\x01\x12\x1a\n\x12weight_a_stitching\x18\n \x01(\x01\x12\x1f\n\x17weight_first_order_time\x18\x0b \x01(\x01\x12 \n\x18weight_second_order_time\x18\x0c \x01(\x01\x12\x1e\n\x13min_safety_distance\x18\r \x01(\x01:\x01\x30\x12\x1c\n\x11max_speed_forward\x18\x0e \x01(\x01:\x01\x33\x12\x1c\n\x11max_speed_reverse\x18\x0f \x01(\x01:\x01\x32\x12#\n\x18max_acceleration_forward\x18\x10 \x01(\x01:\x01\x32\x12#\n\x18max_acceleration_reverse\x18\x11 \x01(\x01:\x01\x32\x12$\n\x17min_time_sample_scaling\x18\x12 \x01(\x01:\x03\x30.1\x12#\n\x17max_time_sample_scaling\x18\x13 \x01(\x01:\x02\x31\x30\x12\x1b\n\x0cuse_fix_time\x18\x14 \x01(\x08:\x05\x66\x61lse\x12\x38\n\x0cipopt_config\x18\x15 \x01(\x0b\x32\".apollo.planning.IpoptSolverConfig\x12\x1f\n\x17\x65nable_constraint_check\x18\x16 \x01(\x08\x12\x1e\n\x16\x65nable_hand_derivative\x18\x17 \x01(\x08\x12\x1f\n\x17\x65nable_derivative_check\x18\x18 \x01(\x08\x12)\n\x1a\x65nable_initial_final_check\x18\x19 \x01(\x08:\x05\x66\x61lse\"\xff\x02\n\x11IpoptSolverConfig\x12\x19\n\x11ipopt_print_level\x18\x01 \x01(\x05\x12\x19\n\x11mumps_mem_percent\x18\x02 \x01(\x05\x12\x14\n\x0cmumps_pivtol\x18\x03 \x01(\x01\x12\x16\n\x0eipopt_max_iter\x18\x04 \x01(\x05\x12\x11\n\tipopt_tol\x18\x05 \x01(\x01\x12(\n ipopt_acceptable_constr_viol_tol\x18\x06 \x01(\x01\x12&\n\x1eipopt_min_hessian_perturbation\x18\x07 \x01(\x01\x12+\n#ipopt_jacobian_regularization_value\x18\x08 \x01(\x01\x12%\n\x1dipopt_print_timing_statistics\x18\t \x01(\t\x12\x19\n\x11ipopt_alpha_for_y\x18\n \x01(\t\x12\x16\n\x0eipopt_recalc_y\x18\x0b \x01(\t\x12\x1a\n\ripopt_mu_init\x18\x0c \x01(\x01:\x03\x30.1*w\n\x10\x44ualVariableMode\x12\x17\n\x13\x44UAL_VARIABLE_IPOPT\x10\x00\x12\x19\n\x15\x44UAL_VARIABLE_IPOPTQP\x10\x01\x12\x16\n\x12\x44UAL_VARIABLE_OSQP\x10\x02\x12\x17\n\x13\x44UAL_VARIABLE_DEBUG\x10\x03'
  ,
  dependencies=[modules_dot_planning_dot_proto_dot_planner__open__space__config__pb2.DESCRIPTOR,])

_DUALVARIABLEMODE = _descriptor.EnumDescriptor(
  name='DualVariableMode',
  full_name='apollo.planning.DualVariableMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_IPOPT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_IPOPTQP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_OSQP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_DEBUG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4240,
  serialized_end=4359,
)
_sym_db.RegisterEnumDescriptor(_DUALVARIABLEMODE)

DualVariableMode = enum_type_wrapper.EnumTypeWrapper(_DUALVARIABLEMODE)
DUAL_VARIABLE_IPOPT = 0
DUAL_VARIABLE_IPOPTQP = 1
DUAL_VARIABLE_OSQP = 2
DUAL_VARIABLE_DEBUG = 3


_OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE = _descriptor.EnumDescriptor(
  name='StopType',
  full_name='apollo.planning.OpenSpacePreStopDeciderConfig.StopType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_DEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_STREET_U_TURN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=543,
  serialized_end=624,
)
_sym_db.RegisterEnumDescriptor(_OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE)

_OPENSPACEROIDECIDERCONFIG_ROITYPE = _descriptor.EnumDescriptor(
  name='RoiType',
  full_name='apollo.planning.OpenSpaceRoiDeciderConfig.RoiType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_DEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_AND_GO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_STREET_U_TURN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1242,
  serialized_end=1339,
)
_sym_db.RegisterEnumDescriptor(_OPENSPACEROIDECIDERCONFIG_ROITYPE)


_OPENSPACEFALLBACKDECIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceFallBackDeciderConfig',
  full_name='apollo.planning.OpenSpaceFallBackDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='open_space_prediction_time_period', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_prediction_time_period', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_fallback_collision_distance', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_fallback_collision_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_fallback_stop_distance', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_fallback_stop_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_fallback_collision_time_buffer', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_fallback_collision_time_buffer', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=359,
)


_OPENSPACEPRESTOPDECIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpacePreStopDeciderConfig',
  full_name='apollo.planning.OpenSpacePreStopDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_type', full_name='apollo.planning.OpenSpacePreStopDeciderConfig.stop_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rightaway_stop_distance', full_name='apollo.planning.OpenSpacePreStopDeciderConfig.rightaway_stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance_to_target', full_name='apollo.planning.OpenSpacePreStopDeciderConfig.stop_distance_to_target', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=624,
)


_OPENSPACEROIDECIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceRoiDeciderConfig',
  full_name='apollo.planning.OpenSpaceRoiDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roi_type', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_longitudinal_range_start', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_longitudinal_range_start', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_longitudinal_range_end', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_longitudinal_range_end', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_start_range', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.parking_start_range', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(7),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_inwards', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.parking_inwards', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_perception_obstacles', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.enable_perception_obstacles', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_depth_buffer', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.parking_depth_buffer', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_line_segment_min_angle', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_line_segment_min_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_line_segment_length', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_line_segment_length', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_line_segment_length_from_map', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_line_segment_length_from_map', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_obstacle_filtering_distance', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.perception_obstacle_filtering_distance', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_obstacle_buffer', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.perception_obstacle_buffer', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curb_heading_tangent_change_upper_limit', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.curb_heading_tangent_change_upper_limit', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_pose_s_distance', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.end_pose_s_distance', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENSPACEROIDECIDERCONFIG_ROITYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=1339,
)


_OPENSPACETRAJECTORYPARTITIONCONFIG = _descriptor.Descriptor(
  name='OpenSpaceTrajectoryPartitionConfig',
  full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_shift_max_t', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.gear_shift_max_t', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_shift_unit_t', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.gear_shift_unit_t', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_shift_period_duration', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.gear_shift_period_duration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interpolated_pieces_num', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.interpolated_pieces_num', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_gear_check_horizon', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.initial_gear_check_horizon', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_search_range', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.heading_search_range', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_track_range', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.heading_track_range', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_search_range', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.distance_search_range', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-06),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_offset_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.heading_offset_to_midpoint', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_offset_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.lateral_offset_to_midpoint', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitudinal_offset_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.longitudinal_offset_to_midpoint', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_box_iou_threshold_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.vehicle_box_iou_threshold_to_midpoint', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.95),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity_threshold_on_ego', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.linear_velocity_threshold_on_ego', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1856,
)


_OPENSPACETRAJECTORYPROVIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceTrajectoryProviderConfig',
  full_name='apollo.planning.OpenSpaceTrajectoryProviderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='open_space_trajectory_optimizer_config', full_name='apollo.planning.OpenSpaceTrajectoryProviderConfig.open_space_trajectory_optimizer_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1995,
)


_OPENSPACETRAJECTORYOPTIMIZERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceTrajectoryOptimizerConfig',
  full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hybrid_a_star_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.hybrid_a_star_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dual_variable_warm_start_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.dual_variable_warm_start_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_approach_trajectory_smoother_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.distance_approach_trajectory_smoother_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_t', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.delta_t', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_near_destination_threshold', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.is_near_destination_threshold', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planner_open_space_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.planner_open_space_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1998,
  serialized_end=2435,
)


_HYBRIDASTARCONFIG = _descriptor.Descriptor(
  name='HybridAStarConfig',
  full_name='apollo.planning.HybridAStarConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xy_grid_resolution', full_name='apollo.planning.HybridAStarConfig.xy_grid_resolution', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phi_grid_resolution', full_name='apollo.planning.HybridAStarConfig.phi_grid_resolution', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_node_num', full_name='apollo.planning.HybridAStarConfig.next_node_num', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step_size', full_name='apollo.planning.HybridAStarConfig.step_size', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_forward_penalty', full_name='apollo.planning.HybridAStarConfig.traj_forward_penalty', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_back_penalty', full_name='apollo.planning.HybridAStarConfig.traj_back_penalty', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_gear_switch_penalty', full_name='apollo.planning.HybridAStarConfig.traj_gear_switch_penalty', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_steer_penalty', full_name='apollo.planning.HybridAStarConfig.traj_steer_penalty', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_steer_change_penalty', full_name='apollo.planning.HybridAStarConfig.traj_steer_change_penalty', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_a_star_xy_resolution', full_name='apollo.planning.HybridAStarConfig.grid_a_star_xy_resolution', index=9,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_radius', full_name='apollo.planning.HybridAStarConfig.node_radius', index=10,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2438,
  serialized_end=2815,
)


_DUALVARIABLECONFIG = _descriptor.Descriptor(
  name='DualVariableConfig',
  full_name='apollo.planning.DualVariableConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_d', full_name='apollo.planning.DualVariableConfig.weight_d', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_config', full_name='apollo.planning.DualVariableConfig.ipopt_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qp_format', full_name='apollo.planning.DualVariableConfig.qp_format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_safety_distance', full_name='apollo.planning.DualVariableConfig.min_safety_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_osqp', full_name='apollo.planning.DualVariableConfig.debug_osqp', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta', full_name='apollo.planning.DualVariableConfig.beta', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2818,
  serialized_end=3047,
)


_DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG = _descriptor.Descriptor(
  name='DistanceApproachTrajectorySmootherConfig',
  full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_steer', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_steer', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_a', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_steer_rate', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_steer_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a_rate', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_a_rate', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_x', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_x', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_y', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_y', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_phi', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_phi', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_v', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_v', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_steer_stitching', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_steer_stitching', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a_stitching', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_a_stitching', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_first_order_time', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_first_order_time', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_second_order_time', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_second_order_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_safety_distance', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.min_safety_distance', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speed_forward', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_speed_forward', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speed_reverse', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_speed_reverse', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration_forward', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_acceleration_forward', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration_reverse', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_acceleration_reverse', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_time_sample_scaling', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.min_time_sample_scaling', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_time_sample_scaling', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_time_sample_scaling', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_fix_time', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.use_fix_time', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_config', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.ipopt_config', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_constraint_check', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_constraint_check', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hand_derivative', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_hand_derivative', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_derivative_check', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_derivative_check', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_initial_final_check', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_initial_final_check', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3050,
  serialized_end=3852,
)


_IPOPTSOLVERCONFIG = _descriptor.Descriptor(
  name='IpoptSolverConfig',
  full_name='apollo.planning.IpoptSolverConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipopt_print_level', full_name='apollo.planning.IpoptSolverConfig.ipopt_print_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mumps_mem_percent', full_name='apollo.planning.IpoptSolverConfig.mumps_mem_percent', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mumps_pivtol', full_name='apollo.planning.IpoptSolverConfig.mumps_pivtol', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_max_iter', full_name='apollo.planning.IpoptSolverConfig.ipopt_max_iter', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_tol', full_name='apollo.planning.IpoptSolverConfig.ipopt_tol', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_acceptable_constr_viol_tol', full_name='apollo.planning.IpoptSolverConfig.ipopt_acceptable_constr_viol_tol', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_min_hessian_perturbation', full_name='apollo.planning.IpoptSolverConfig.ipopt_min_hessian_perturbation', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_jacobian_regularization_value', full_name='apollo.planning.IpoptSolverConfig.ipopt_jacobian_regularization_value', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_print_timing_statistics', full_name='apollo.planning.IpoptSolverConfig.ipopt_print_timing_statistics', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_alpha_for_y', full_name='apollo.planning.IpoptSolverConfig.ipopt_alpha_for_y', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_recalc_y', full_name='apollo.planning.IpoptSolverConfig.ipopt_recalc_y', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_mu_init', full_name='apollo.planning.IpoptSolverConfig.ipopt_mu_init', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3855,
  serialized_end=4238,
)

_OPENSPACEPRESTOPDECIDERCONFIG.fields_by_name['stop_type'].enum_type = _OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE
_OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE.containing_type = _OPENSPACEPRESTOPDECIDERCONFIG
_OPENSPACEROIDECIDERCONFIG.fields_by_name['roi_type'].enum_type = _OPENSPACEROIDECIDERCONFIG_ROITYPE
_OPENSPACEROIDECIDERCONFIG_ROITYPE.containing_type = _OPENSPACEROIDECIDERCONFIG
_OPENSPACETRAJECTORYPROVIDERCONFIG.fields_by_name['open_space_trajectory_optimizer_config'].message_type = _OPENSPACETRAJECTORYOPTIMIZERCONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['hybrid_a_star_config'].message_type = _HYBRIDASTARCONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['dual_variable_warm_start_config'].message_type = _DUALVARIABLECONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['distance_approach_trajectory_smoother_config'].message_type = _DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['planner_open_space_config'].message_type = modules_dot_planning_dot_proto_dot_planner__open__space__config__pb2._PLANNEROPENSPACECONFIG
_DUALVARIABLECONFIG.fields_by_name['ipopt_config'].message_type = _IPOPTSOLVERCONFIG
_DUALVARIABLECONFIG.fields_by_name['qp_format'].enum_type = _DUALVARIABLEMODE
_DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG.fields_by_name['ipopt_config'].message_type = _IPOPTSOLVERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceFallBackDeciderConfig'] = _OPENSPACEFALLBACKDECIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpacePreStopDeciderConfig'] = _OPENSPACEPRESTOPDECIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceRoiDeciderConfig'] = _OPENSPACEROIDECIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceTrajectoryPartitionConfig'] = _OPENSPACETRAJECTORYPARTITIONCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceTrajectoryProviderConfig'] = _OPENSPACETRAJECTORYPROVIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceTrajectoryOptimizerConfig'] = _OPENSPACETRAJECTORYOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['HybridAStarConfig'] = _HYBRIDASTARCONFIG
DESCRIPTOR.message_types_by_name['DualVariableConfig'] = _DUALVARIABLECONFIG
DESCRIPTOR.message_types_by_name['DistanceApproachTrajectorySmootherConfig'] = _DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG
DESCRIPTOR.message_types_by_name['IpoptSolverConfig'] = _IPOPTSOLVERCONFIG
DESCRIPTOR.enum_types_by_name['DualVariableMode'] = _DUALVARIABLEMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OpenSpaceFallBackDeciderConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceFallBackDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACEFALLBACKDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceFallBackDeciderConfig)
  })
_sym_db.RegisterMessage(OpenSpaceFallBackDeciderConfig)

OpenSpacePreStopDeciderConfig = _reflection.GeneratedProtocolMessageType('OpenSpacePreStopDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACEPRESTOPDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpacePreStopDeciderConfig)
  })
_sym_db.RegisterMessage(OpenSpacePreStopDeciderConfig)

OpenSpaceRoiDeciderConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceRoiDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACEROIDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceRoiDeciderConfig)
  })
_sym_db.RegisterMessage(OpenSpaceRoiDeciderConfig)

OpenSpaceTrajectoryPartitionConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceTrajectoryPartitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACETRAJECTORYPARTITIONCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceTrajectoryPartitionConfig)
  })
_sym_db.RegisterMessage(OpenSpaceTrajectoryPartitionConfig)

OpenSpaceTrajectoryProviderConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceTrajectoryProviderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACETRAJECTORYPROVIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceTrajectoryProviderConfig)
  })
_sym_db.RegisterMessage(OpenSpaceTrajectoryProviderConfig)

OpenSpaceTrajectoryOptimizerConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceTrajectoryOptimizerConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACETRAJECTORYOPTIMIZERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceTrajectoryOptimizerConfig)
  })
_sym_db.RegisterMessage(OpenSpaceTrajectoryOptimizerConfig)

HybridAStarConfig = _reflection.GeneratedProtocolMessageType('HybridAStarConfig', (_message.Message,), {
  'DESCRIPTOR' : _HYBRIDASTARCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.HybridAStarConfig)
  })
_sym_db.RegisterMessage(HybridAStarConfig)

DualVariableConfig = _reflection.GeneratedProtocolMessageType('DualVariableConfig', (_message.Message,), {
  'DESCRIPTOR' : _DUALVARIABLECONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DualVariableConfig)
  })
_sym_db.RegisterMessage(DualVariableConfig)

DistanceApproachTrajectorySmootherConfig = _reflection.GeneratedProtocolMessageType('DistanceApproachTrajectorySmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DistanceApproachTrajectorySmootherConfig)
  })
_sym_db.RegisterMessage(DistanceApproachTrajectorySmootherConfig)

IpoptSolverConfig = _reflection.GeneratedProtocolMessageType('IpoptSolverConfig', (_message.Message,), {
  'DESCRIPTOR' : _IPOPTSOLVERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.IpoptSolverConfig)
  })
_sym_db.RegisterMessage(IpoptSolverConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/data/proto/frame.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/data/proto/frame.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1emodules/data/proto/frame.proto\"*\n\x07Vector3\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"O\n\x07Vector4\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01i\x18\x04 \x01(\x01\x12\x18\n\tis_ground\x18\x05 \x01(\x08:\x05\x66\x61lse\"8\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01w\x18\x04 \x01(\x01\"\x85\x01\n\x07GPSPose\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lon\x18\x02 \x01(\x01\x12\x0f\n\x07\x62\x65\x61ring\x18\x03 \x01(\x01\x12\t\n\x01x\x18\x04 \x01(\x01\x12\t\n\x01y\x18\x05 \x01(\x01\x12\t\n\x01z\x18\x06 \x01(\x01\x12\n\n\x02qw\x18\x07 \x01(\x01\x12\n\n\x02qx\x18\x08 \x01(\x01\x12\n\n\x02qy\x18\t \x01(\x01\x12\n\n\x02qz\x18\n \x01(\x01\"\xf8\x01\n\x0b\x43\x61meraImage\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x11\n\timage_url\x18\x02 \x01(\t\x12\x1a\n\x08position\x18\x03 \x01(\x0b\x32\x08.Vector3\x12\x1c\n\x07heading\x18\x04 \x01(\x0b\x32\x0b.Quaternion\x12\n\n\x02\x66x\x18\x05 \x01(\x01\x12\n\n\x02\x66y\x18\x06 \x01(\x01\x12\n\n\x02\x63x\x18\x07 \x01(\x01\x12\n\n\x02\x63y\x18\x08 \x01(\x01\x12\x0c\n\x04skew\x18\t \x01(\x01\x12\n\n\x02k1\x18\n \x01(\x01\x12\n\n\x02k2\x18\x0b \x01(\x01\x12\n\n\x02k3\x18\x0c \x01(\x01\x12\n\n\x02p1\x18\r \x01(\x01\x12\n\n\x02p2\x18\x0e \x01(\x01\x12\x0f\n\x07\x63hannel\x18\x0f \x01(\t\"\x8c\x01\n\nRadarPoint\x12\x1a\n\x08position\x18\x01 \x01(\x0b\x32\x08.Vector3\x12\x1b\n\tdirection\x18\x02 \x01(\x0b\x32\x08.Vector3\x12#\n\x04type\x18\x03 \x01(\x0e\x32\x15.RadarPoint.RadarType\" \n\tRadarType\x12\t\n\x05\x46RONT\x10\x01\x12\x08\n\x04REAR\x10\x02\"\x86\x02\n\x05\x46rame\x12!\n\x0f\x64\x65vice_position\x18\x01 \x01(\x0b\x32\x08.Vector3\x12#\n\x0e\x64\x65vice_heading\x18\x02 \x01(\x0b\x32\x0b.Quaternion\x12!\n\x0f\x64\x65vice_gps_pose\x18\x03 \x01(\x0b\x32\x08.GPSPose\x12\x18\n\x06points\x18\x04 \x03(\x0b\x32\x08.Vector4\x12!\n\x0cradar_points\x18\x05 \x03(\x0b\x32\x0b.RadarPoint\x12\x1c\n\x06images\x18\x06 \x03(\x0b\x32\x0c.CameraImage\x12\x11\n\ttimestamp\x18\x07 \x01(\x01\x12\x11\n\tframe_seq\x18\x08 \x01(\x05\x12\x11\n\tdata_file\x18\t \x01(\t'
)



_RADARPOINT_RADARTYPE = _descriptor.EnumDescriptor(
  name='RadarType',
  full_name='RadarPoint.RadarType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FRONT', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REAR', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=713,
  serialized_end=745,
)
_sym_db.RegisterEnumDescriptor(_RADARPOINT_RADARTYPE)


_VECTOR3 = _descriptor.Descriptor(
  name='Vector3',
  full_name='Vector3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='Vector3.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='Vector3.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='Vector3.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=76,
)


_VECTOR4 = _descriptor.Descriptor(
  name='Vector4',
  full_name='Vector4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='Vector4.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='Vector4.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='Vector4.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i', full_name='Vector4.i', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ground', full_name='Vector4.is_ground', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=157,
)


_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='Quaternion.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='Quaternion.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='Quaternion.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='Quaternion.w', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=215,
)


_GPSPOSE = _descriptor.Descriptor(
  name='GPSPose',
  full_name='GPSPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat', full_name='GPSPose.lat', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lon', full_name='GPSPose.lon', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bearing', full_name='GPSPose.bearing', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='GPSPose.x', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='GPSPose.y', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='GPSPose.z', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qw', full_name='GPSPose.qw', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qx', full_name='GPSPose.qx', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qy', full_name='GPSPose.qy', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qz', full_name='GPSPose.qz', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=351,
)


_CAMERAIMAGE = _descriptor.Descriptor(
  name='CameraImage',
  full_name='CameraImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CameraImage.timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_url', full_name='CameraImage.image_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='CameraImage.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='CameraImage.heading', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fx', full_name='CameraImage.fx', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fy', full_name='CameraImage.fy', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cx', full_name='CameraImage.cx', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cy', full_name='CameraImage.cy', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skew', full_name='CameraImage.skew', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k1', full_name='CameraImage.k1', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k2', full_name='CameraImage.k2', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k3', full_name='CameraImage.k3', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p1', full_name='CameraImage.p1', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p2', full_name='CameraImage.p2', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='CameraImage.channel', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=602,
)


_RADARPOINT = _descriptor.Descriptor(
  name='RadarPoint',
  full_name='RadarPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='RadarPoint.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='RadarPoint.direction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='RadarPoint.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RADARPOINT_RADARTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=745,
)


_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_position', full_name='Frame.device_position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_heading', full_name='Frame.device_heading', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_gps_pose', full_name='Frame.device_gps_pose', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='Frame.points', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_points', full_name='Frame.radar_points', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='images', full_name='Frame.images', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='Frame.timestamp', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_seq', full_name='Frame.frame_seq', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_file', full_name='Frame.data_file', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=1010,
)

_CAMERAIMAGE.fields_by_name['position'].message_type = _VECTOR3
_CAMERAIMAGE.fields_by_name['heading'].message_type = _QUATERNION
_RADARPOINT.fields_by_name['position'].message_type = _VECTOR3
_RADARPOINT.fields_by_name['direction'].message_type = _VECTOR3
_RADARPOINT.fields_by_name['type'].enum_type = _RADARPOINT_RADARTYPE
_RADARPOINT_RADARTYPE.containing_type = _RADARPOINT
_FRAME.fields_by_name['device_position'].message_type = _VECTOR3
_FRAME.fields_by_name['device_heading'].message_type = _QUATERNION
_FRAME.fields_by_name['device_gps_pose'].message_type = _GPSPOSE
_FRAME.fields_by_name['points'].message_type = _VECTOR4
_FRAME.fields_by_name['radar_points'].message_type = _RADARPOINT
_FRAME.fields_by_name['images'].message_type = _CAMERAIMAGE
DESCRIPTOR.message_types_by_name['Vector3'] = _VECTOR3
DESCRIPTOR.message_types_by_name['Vector4'] = _VECTOR4
DESCRIPTOR.message_types_by_name['Quaternion'] = _QUATERNION
DESCRIPTOR.message_types_by_name['GPSPose'] = _GPSPOSE
DESCRIPTOR.message_types_by_name['CameraImage'] = _CAMERAIMAGE
DESCRIPTOR.message_types_by_name['RadarPoint'] = _RADARPOINT
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vector3 = _reflection.GeneratedProtocolMessageType('Vector3', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR3,
  '__module__' : 'modules.data.proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:Vector3)
  })
_sym_db.RegisterMessage(Vector3)

Vector4 = _reflection.GeneratedProtocolMessageType('Vector4', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR4,
  '__module__' : 'modules.data.proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:Vector4)
  })
_sym_db.RegisterMessage(Vector4)

Quaternion = _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNION,
  '__module__' : 'modules.data.proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:Quaternion)
  })
_sym_db.RegisterMessage(Quaternion)

GPSPose = _reflection.GeneratedProtocolMessageType('GPSPose', (_message.Message,), {
  'DESCRIPTOR' : _GPSPOSE,
  '__module__' : 'modules.data.proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:GPSPose)
  })
_sym_db.RegisterMessage(GPSPose)

CameraImage = _reflection.GeneratedProtocolMessageType('CameraImage', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAIMAGE,
  '__module__' : 'modules.data.proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:CameraImage)
  })
_sym_db.RegisterMessage(CameraImage)

RadarPoint = _reflection.GeneratedProtocolMessageType('RadarPoint', (_message.Message,), {
  'DESCRIPTOR' : _RADARPOINT,
  '__module__' : 'modules.data.proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:RadarPoint)
  })
_sym_db.RegisterMessage(RadarPoint)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), {
  'DESCRIPTOR' : _FRAME,
  '__module__' : 'modules.data.proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:Frame)
  })
_sym_db.RegisterMessage(Frame)


# @@protoc_insertion_point(module_scope)
